/* Copyright 2017-2024 The MathWorks, Inc. */
'use strict';

var URL = MM.getURL();
var domain = "*";
var cachedUsername = MM.getCachedUsername();
var unauthorizedText = MM.getUnauthorizedText();
var platform = MM.getPlatform();
var release = MM.getRelease();

var mode = MM.getMode();
var modeOption = MM.getModeOption();
var identityToken = MM.getToken();
var mfaToken = MM.getMFAToken();
var clientId = MM.getClientID();

var connectionInfo = {
    clientTransactionId: "",
    transactionId: ""
};

var iframe = document.getElementById("iframe");

var generateClientTransactionId = function() {
    // Generate a random int in range of [1, 100000000]
    // Based on Adam, there is no limit on the length of the nonce yet
    return Math.floor(Math.random() * 100000000 + 1);
};

var buildInitRequest = function() {
    return {
      "event": "init",
      "clientTransactionId": generateClientTransactionId.toString(),
      "transactionId": "",
      "release": "",
      "platform": "",
      "clientString": "",
      "clientId": clientId,
      "locale": "",
      "profileTier": "",
      "showCreateAccount": false,
      "showRememberMe": false,
      "showLicenseField": false,
      "licenseNo": "",
      "cachedUsername": "",
      "cachedRememberMe": false
    };
};

var buildGoBackRequest = function() {
    return {
        "event": "back",
        "clientTransactionId": connectionInfo.clientTransactionId,
        "transactionId": connectionInfo.transactionId
    };
};

var buildLoadRequest = function(clientTransactionId, transactionId) {
    return {
        "event": "load",
        "transactionId": transactionId,
        "clientTransactionId": clientTransactionId,
        "release": release,
        "platform": platform,
        "clientString": "MOBILE",
        "clientId": clientId,
        "profileTier": "extended",
        "mode": mode,
        "modeOption": modeOption,
        "showCreateAccount": true,
        "showRememberMe": false,
        "entitlementId": "",
        "showPrivacyPolicy": true,
        "contextualText": "",
        "contextualErrorText": "",
        "contextualProfileText": "",
        "restrictEmailDomain": false,
//        "autoAssociate": false, //g3313270 - use the default value of true
        "licenseReference": "",
        "legalText": "",
        "cachedUsername": cachedUsername,
        "identifierReadOnly": false,
        "cachedRememberMe": false,
        "requireAssociation": false,
        "token": identityToken,
        "mfaToken": mfaToken,
        "unauthorized": false,
        "unauthorizedText": unauthorizedText
    };
};

var receiveMessage = function(event) {
    if (event.origin.indexOf(".mathworks.com") == -1) {
        // event is not from the embedded forms, ignore
        return;
    }

    var data = JSON.parse(event.data);

    var transactionId;
    var clientTransactionId;
    var formHeight;

    switch (data.event) {
        case "nonce":
            connectionInfo.transactionId = data.transactionId;
            connectionInfo.clientTransactionId = data.clientTransactionId;

            formHeight = data.formHeight; // formHeight is in unit of px

            iframe.contentWindow.postMessage(JSON.stringify(buildLoadRequest(data.clientTransactionId, data.transactionId)), domain);
            MM.onNonceEstablished();
            break;

        case "login":
            var identityToken = data.token;
            var accessToken = data.accessToken;
            if (!accessToken) accessToken = "";

            var firstName = data.firstName;
            var lastName = data.lastName;
            var userID = data.userID;
            var emailAddress = data.emailAddress;
            var cachedUsername = data.cachedUsername;
            var profileId = data.profileId;
            var profilePic = data.profilePic;
            var transactionId = data.transactionId;
            var clientTransactionId = data.clientTransactionId;
            var rememberMe = data.rememberMe;
            var errors = data.errors;
            var mfaToken = data.mfaToken;
            if (!mfaToken) {
                mfaToken = "";
            }

//            console.log("clientId: " + clientId);
//            console.log("identityToken: " + identityToken);
//            console.log("accessToken: " + accessToken);
//            console.log("mfaToken: " + mfaToken);

            MM.onLoginSucceeded(identityToken, accessToken, mfaToken, profileId, userID, cachedUsername, firstName, lastName, emailAddress);

            break;

        case "cancel":
            MM.onBackPressedOnInitialScreen();
            break;
    }

};

iframe.onload = function() {
    iframe.contentWindow.postMessage(JSON.stringify(buildInitRequest()), domain);
};

// Bootstrap embedded login form process.
window.onload = function() {
    iframe.src = URL;
};

// The response from iframe is a "message" event that we need to listen to.
window.addEventListener('message', receiveMessage, false);

// This is required so that QUnit tests could run.
window.onerror = function(e) {
    //console.log(e);
};

var goBack = function() {
    iframe.contentWindow.postMessage(JSON.stringify(buildGoBackRequest()), domain);
};
